#!/bin/bash
cd ner/


for NUM_SENTENCES in 50
do
    for PART in 1 2 3 4 5 6 7 8 9 10
    do
        # Baselines
        # CoNLL 2003
        ## 3 Classes (grouped into BIO - not used in the paper)
        ### Standard MultiClass CE
        python train.py --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        ### CRF
        python train.py --crfopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        ### BiLSTM-CRF
        python train.py --bilstmopt --crfopt --learning_rate=3e-4 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        ### OVA-BCE
        python train.py --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0


        ## 9 Classes (Original Table 4 in the paper)
        ### Standard MultiClass CE
        python train.py --num_class=9 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        ### CRF
        python train.py --num_class=9 --crfopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        ### BiLSTM-CRF
        python train.py --num_class=9 --bilstmopt --crfopt --learning_rate=3e-4 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        ### OVA-BCE
        python train.py --num_class=9 --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0

        ## Ensembles
        python train.py --ensembleopt --num_ensembles=5 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --ensembleopt --num_ensembles=5 --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --ensembleopt --num_ensembles=5 --num_class=9 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --ensembleopt --num_ensembles=5 --num_class=9 --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0

        # OntoNotes 5
        ## 3 classes
        python train.py --corpus="ontonotes5" --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="ontonotes5" --crfopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="ontonotes5" --bilstmopt --crfopt --learning_rate=3e-4 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="ontonotes5" --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0

        ## 37 Classes
        python train.py --corpus="ontonotes5" --num_class=37 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="ontonotes5" --num_class=37 --crfopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="ontonotes5" --num_class=37 --bilstmopt --crfopt --learning_rate=3e-4 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="ontonotes5" --num_class=37 --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0

        ## Ensembles
        python train.py --ensembleopt --num_ensembles=5 --corpus="ontonotes5" --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --ensembleopt --num_ensembles=5 --corpus="ontonotes5" --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --ensembleopt --num_ensembles=5 --corpus="ontonotes5" --num_class=37 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --ensembleopt --num_ensembles=5 --corpus="ontonotes5" --num_class=37 --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0


        # NCBI
        ## 3 Classes
        python train.py --corpus="NCBI" --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="NCBI" --crfopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="NCBI" --bilstmopt --crfopt --learning_rate=3e-4 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="NCBI" --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        
        ## Ensembles
        python train.py --ensembleopt --num_ensembles=5 --corpus="NCBI" --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --ensembleopt --num_ensembles=5 --corpus="NCBI" --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0

        # s800
        python train.py --corpus="s800" --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="s800" --crfopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="s800" --bilstmopt --crfopt --learning_rate=3e-4 --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --corpus="s800" --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0

        ## Ensembles
        python train.py --ensembleopt --num_ensembles=5 --corpus="s800" --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
        python train.py --ensembleopt --num_ensembles=5 --corpus="s800" --onevsall --ceopt --num_training_sentences=$NUM_SENTENCES --part=$PART --n_gpu=1 --gpu_no=0
    done
done


cd ..